@@ -5,19 +5,19 @@
 
 #' Pairwise LD estimation in polyploids.
 #'
-#' Estimates either gametic or composite measures of LD using either
+#' Estimates either haplotypic or composite measures of LD using either
 #' genotypes are genotype likelihoods. The usual measures of LD are
 #' estimated (D, D', and r) along with the Fisher-z transformation of
 #' r (called "z"). All estimates are returned with standard errors.
 #'
-#' @section Gametic LD:
+#' @section Haplotypic LD:
 #'
-#' This section describes the methods used when \code{type = "gam"} is
+#' This section describes the methods used when \code{type = "hap"} is
 #' selected.
 #'
-#' Gametic LD measures the association
-#' between two loci on the same gamete. When haplotypes are known, estimating
-#' gametic LD is simple using just the haplotypic frequencies.
+#' Haplotypic LD measures the association
+#' between two loci on the same haplotype. When haplotypes are known, estimating
+#' haplotypic LD is simple using just the haplotypic frequencies.
 #'
 #' When haplotypes are not known, we can still estimate haplotypic frequencies
 #' using the genotypes or genotype likelihoods
@@ -25,13 +25,13 @@
 #' this via maximum likelihood using gradient ascent. Gradient ascent is
 #' performed over the unconstrained parameterization of the 3-simplex from
 #' Betancourt (2012). The estimated haplotype frequencies are then used to
-#' estimate gametic LD.
+#' estimate haplotypic LD.
 #'
 #' Standard errors are provided using standard maximum likelihood theory.
 #' In brief, the Hessian matrix of the log-likelihood is calculated at
 #' the MLE's of the haplotype frequencies. The negative inverse of this
 #' Hessian matrix is approximately the covariance matrix of the MLE's of the
-#' haplotype frequencies. Since all gametic LD measures are functions
+#' haplotype frequencies. Since all haplotypic LD measures are functions
 #' of the haplotype frequencies, we use the delta-method to obtain
 #' the standard errors for each LD estimate.
 #'
@@ -40,7 +40,7 @@
 #' of Agresti (1998). You can change this prior via the \code{pen} argument.
 #'
 #' When you either do not have autopolyploids or when HWE is \emph{not}
-#' satisfied, then the estimates using \code{type = "gam"}
+#' satisfied, then the estimates using \code{type = "hap"}
 #' are nonsensical. However, the composite measures of LD are still
 #' applicable (see below).
 #'
@@ -51,8 +51,8 @@
 #'
 #' When HWE is not satisfied, haplotype frequencies are not estimable. However,
 #' measures of association between two loci are still estimable. These
-#' associations may be caused by LD either on the same gamete or between
-#' different gametes. Cockerham and Weir (1977) thus called such measures
+#' associations may be caused by LD either on the same haplotype or between
+#' different haplotypes. Cockerham and Weir (1977) thus called such measures
 #' "composite" measures of LD.
 #'
 #' When the genotypes are known, these composite measures have simple
@@ -67,14 +67,14 @@
 #' either follow a proportional bivariate normal model (by default) or
 #' a general categorical model.
 #'
-#' These estimates of composite measures of LD estimate the gametic
+#' These estimates of composite measures of LD estimate the haplotypic
 #' measures of LD when HWE is fulfilled, but are still applicable when HWE
 #' is not fulfilled.
 #'
 #' When genotypes are known, standard errors are calculated using standard
 #' moment-based approaches. When genotypes are not known, standard
 #' errors are calculated using standard maximum likelihood theory,
-#' same as for the gametic LD estimates (see above), or using
+#' same as for the haplotypic LD estimates (see above), or using
 #' a bootstrap.
 #'
 #' @param ga One of two possible inputs:
@@ -102,8 +102,8 @@
 #' @param K The ploidy of the species. Assumed to be the same for all
 #'     individuals.
 #' @param type The type of LD to calculate. The available types are
-#'     gametic LD (\code{type = "gam"}) or composite LD
-#'     (\code{type = "comp"}). Gametic LD is only appropriate for
+#'     haplotypic LD (\code{type = "hap"}) or composite LD
+#'     (\code{type = "comp"}). Haplotypic LD is only appropriate for
 #'     autopolyploids when the individuals are in Hardy-Weinberg
 #'     equilibrium (HWE). The composite
 #'     measures of LD are always applicable, and consistently estimate the
@@ -149,13 +149,13 @@
 #'   \item{\code{z_se}}{The standard error of the Fisher-z
 #'       transformation of \code{r}.}
 #'   \item{\code{p_ab}}{The estimated haplotype frequency of ab.
-#'       Only returned if estimating the gametic LD.}
+#'       Only returned if estimating the haplotypic LD.}
 #'   \item{\code{p_Ab}}{The estimated haplotype frequency of Ab.
-#'       Only returned if estimating the gametic LD.}
+#'       Only returned if estimating the haplotypic LD.}
 #'   \item{\code{p_aB}}{The estimated haplotype frequency of aB.
-#'       Only returned if estimating the gametic LD.}
+#'       Only returned if estimating the haplotypic LD.}
 #'   \item{\code{p_AB}}{The estimated haplotype frequency of AB.
-#'       Only returned if estimating the gametic LD.}
+#'       Only returned if estimating the haplotypic LD.}
 #'   \item{\code{q_ij}}{The estimated frequency of genotype i at locus 1
 #'       and genotype j at locus 2. Only returned if estimating the
 #'       composite LD.}
@@ -179,18 +179,18 @@
 #' head(gamat)
 #' head(gbmat)
 #'
-#' ## Gametic LD with genotypes
+#' ## Haplotypic LD with genotypes
 #' ldout1 <- ldest(ga = ga,
 #'                 gb = gb,
 #'                 K = K,
-#'                 type = "gam")
+#'                 type = "hap")
 #' head(ldout1)
 #'
-#' ## Gametic LD with genotype likelihoods
+#' ## Haplotypic LD with genotype likelihoods
 #' ldout2 <- ldest(ga = gamat,
 #'                 gb = gbmat,
 #'                 K = K,
-#'                 type = "gam")
+#'                 type = "hap")
 #' head(ldout2)
 #'
 #' ## Composite LD with genotypes
@@ -231,8 +231,8 @@
 #'       pairs of a collection of SNPs.}
 #'   \item{\code{\link{sldest}()}}{For calculating pairwise LD along a
 #'       sliding window of SNPs.}
-#'   \item{\code{\link{ldest_gam}()}}{For the function that directly estimates
-#'       gametic LD when HWE is fulfilled.}
+#'   \item{\code{\link{ldest_hap}()}}{For the function that directly estimates
+#'       haplotypic LD when HWE is fulfilled.}
 #'   \item{\code{\link{ldest_comp}()}}{For the function that directly
 #'       estimates composite LD.}
 #' }
@@ -256,15 +256,15 @@ ldest <- function(ga,
                   gb,
                   K,
                   se = TRUE,
-                  type = c("gam", "comp"),
+                  type = c("hap", "comp"),
                   model = c("norm", "flex"),
-                  pen = ifelse(type == "gam", 2, 1)) {
+                  pen = ifelse(type == "hap", 2, 1)) {
   type <- match.arg(type)
   model <- match.arg(model)
   stopifnot(is.logical(se))
 
-  if (type == "gam") {
-    retvec <- ldest_gam(ga  = ga,
+  if (type == "hap") {
+    retvec <- ldest_hap(ga  = ga,
                         gb  = gb,
                         K   = K,
                         pen = pen,
@@ -408,7 +408,7 @@ convert_ld <- function(phat) {
   return(retvec)
 }
 
-#' Estimate gametic pair-wise LD using either genotypes or genotype
+#' Estimate haplotypic pair-wise LD using either genotypes or genotype
 #' likelihoods.
 #'
 #' Given genotype (allele dosage) or genotype likelihood data
@@ -490,20 +490,20 @@ convert_ld <- function(phat) {
 #' head(gamat)
 #' head(gbmat)
 #'
-#' ## Gametic LD with genotypes
-#' ldout1 <- ldest_gam(ga = ga,
+#' ## Haplotypic LD with genotypes
+#' ldout1 <- ldest_hap(ga = ga,
 #'                     gb = gb,
 #'                     K = K)
 #' head(ldout1)
 #'
-#' ## Gametic LD with genotype likelihoods
-#' ldout2 <- ldest_gam(ga = gamat,
+#' ## Haplotypic LD with genotype likelihoods
+#' ldout2 <- ldest_hap(ga = gamat,
 #'                     gb = gbmat,
 #'                     K = K)
 #' head(ldout2)
 #'
 #' @export
-ldest_gam <- function(ga,
+ldest_hap <- function(ga,
                       gb,
                       K,
                       reltol  = 10^-8,
@@ -668,7 +668,7 @@ ldest_gam <- function(ga,
   return(retvec)
 }
 
-#' The null return value when estimating gametic LD
+#' The null return value when estimating haplotypic LD
 #'
 #' @param K the ploidy of the species
 #'
